@@ -4,6 +4,11 @@
 ###############################################################################
 
 
+# Names that should be suppressed from global variable check by codetools
+# Names used broadly should be put in _global_variables.R
+globalVariables(c("prior"))
+
+
 #' Parse distribution specifications into columns of a data frame
 #'
 #' Parses simple string distribution specifications, like `"normal(0, 1)"`, into two columns of
@@ -132,9 +137,14 @@ parse_dist.character = function(object, ..., dist = ".dist", args = ".args", to_
 #' @rdname parse_dist
 #' @export
 parse_dist.factor = function(object, ..., dist = ".dist", args = ".args", to_r_names = TRUE) {
-  parse_dist(as.character(object))
+  parse_dist(as.character(object), ..., dist = dist, args = args, to_r_names = to_r_names)
 }
 
+#' @rdname parse_dist
+#' @export
+parse_dist.brmsprior = function(object, dist_col = prior, ..., dist = ".dist", args = ".args", to_r_names = TRUE) {
+  parse_dist.data.frame(as.data.frame(object), {{ dist_col }}, ..., dist = dist, args = args, to_r_names = to_r_names)
+}
 
 
 # r_dist_name -------------------------------------------------------------
